package com.pj.project.tb_vehicle;

import java.io.FileOutputStream;
import java.io.IOException;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.pj.project.tb_driver.TbDriver;
import com.pj.utils.so.SoMap;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.transaction.annotation.Transactional;
import com.pj.utils.sg.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * Service: tb_vehicle -- 车辆
 * @author loovi 
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class TbVehicleService extends ServiceImpl<TbVehicleMapper, TbVehicle> implements IService<TbVehicle>{

	/** 底层 Mapper 对象 */
	@Autowired
	TbVehicleMapper tbVehicleMapper;

	@Autowired
	private MethodVehicleService methodVehicleService;

	/** 增 */
	void add(TbVehicle t){
		save(t);
	}

	/** 删 */
	void delete(Long id){
		removeById(id);
	}

	/** 改 */
	void update(TbVehicle t){
		updateById(t);

	}

	/** 查 */
	TbVehicle getById(Long id){
		return super.getById(id);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */  
	List<TbVehicle> getList(SoMap so) { 
		return tbVehicleMapper.getList(so);	
	}

	/**
	 * 导入
	 * @param file excel文件
	 * @return
	 * @throws IOException
	 */
	public String importData(MultipartFile file) throws IOException {
		System.out.println("\n开始执行文件上传....\n");

		//判空
		if(file.isEmpty()) return "文件为空,无法执行上传...";
		//获取文件上传数据
		HSSFWorkbook wb = new HSSFWorkbook(file.getInputStream());
		//获取第一页sheet
		HSSFSheet sheet = wb.getSheetAt(0);
		//定义计数器
		int count = 0;
		//定义行对象
		HSSFRow row = null;
		//解析数据封装到集合
		count = methodVehicleService.importMethod(row, sheet, count);
		wb.close();
		System.out.println("\n文件上传完成,共上传 " + count + "条 " + "数据...\n");
		return "上传完成,共上传"  + count + "条"  + "数据。";
	}

	/**
	 * 导出 excel文件
	 * @param keyword
	 * @return
	 */
	public String outportExcel(String keyword) throws IOException {
		System.out.println("\n开始执行文件导出....\n");
		//路径
		String localPath = "C:\\Users\\Administrator\\Desktop\\generate\\";
		String filepath = localPath + "车辆信息数据表_" + LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyy-MM-dd")) + ".xlsx";
		//根据需求查询数据
		List<TbVehicle> selectedList = tbVehicleMapper.selectList(new LambdaQueryWrapper<TbVehicle>().eq(StringUtils.isNoneBlank(keyword), TbVehicle::getOwner, keyword));
		if(selectedList.size() == 0)return "没有可导出的数据。";
		//建立excel对象封装数据
		HSSFWorkbook workbook = new HSSFWorkbook();
		//创建excel表格右下角的sheet页名称
		HSSFSheet sheet = workbook.createSheet("1");
		//创建表头
		HSSFRow row = sheet.createRow(0);
		row.createCell(0).setCellValue("序号");
		row.createCell(1).setCellValue("车辆");
		row.createCell(2).setCellValue("所有人");
		row.createCell(3).setCellValue("车辆类型");
		row.createCell(4).setCellValue("类型父id");
		row.createCell(5).setCellValue("车辆尺寸");
		row.createCell(6).setCellValue("车辆品牌型号");
		row.createCell(7).setCellValue("核定载质量");
		row.createCell(8).setCellValue("车辆自重");
		row.createCell(9).setCellValue("审核状态");
		row.createCell(10).setCellValue("审核人");
		row.createCell(11).setCellValue("审核不通过原因");
		row.createCell(12).setCellValue("审核时间");

		row.createCell(13).setCellValue("创建时间");
		row.createCell(14).setCellValue("创建人编号");
		row.createCell(15).setCellValue("创建人名称");
		row.createCell(16).setCellValue("更新时间");
		row.createCell(17).setCellValue("更新人编号");
		row.createCell(18).setCellValue("更新人名称");
		row.createCell(19).setCellValue("删除状态");

		//遍历集合
		for (int i = 0; i < selectedList.size(); i++) {
			HSSFRow sheetRow = sheet.createRow(sheet.getLastRowNum() + 1);
			sheetRow.createCell(0).setCellValue(i + 1);
			sheetRow.createCell(1).setCellValue((selectedList.get(i).getVehiclePlate() + "").equals("null")? "": selectedList.get(i).getVehiclePlate() + "");
			sheetRow.createCell(2).setCellValue((selectedList.get(i).getOwner() + "").equals("null")? "": selectedList.get(i).getOwner() + "");
			sheetRow.createCell(3).setCellValue((selectedList.get(i).getVehicleType() + "").equals("null")? "": selectedList.get(i).getVehicleType() + "");
			sheetRow.createCell(4).setCellValue((selectedList.get(i).getParentId() + "").equals("null")? "": selectedList.get(i).getParentId() + "");
			sheetRow.createCell(5).setCellValue((selectedList.get(i).getVehicleSize() + "").equals("null")? "": selectedList.get(i).getVehicleSize() + "");
			sheetRow.createCell(6).setCellValue((selectedList.get(i).getVehicleModel() + "").equals("null")? "": selectedList.get(i).getVehicleModel() + "");
			sheetRow.createCell(7).setCellValue((selectedList.get(i).getVehicleLoad() + "").equals("null")? "": selectedList.get(i).getVehicleLoad() + "");
			sheetRow.createCell(8).setCellValue((selectedList.get(i).getVehicleWeight() + "" ).equals("null")? "": selectedList.get(i).getVehicleWeight() + "");
			sheetRow.createCell(9).setCellValue((selectedList.get(i).getAuditStatus() + "").equals("null")? "": selectedList.get(i).getAuditStatus() + "");
			sheetRow.createCell(10).setCellValue((selectedList.get(i).getAuditBy() + "").equals("null")? "": selectedList.get(i).getAuditBy() + "");
			sheetRow.createCell(11).setCellValue((selectedList.get(i).getNopassReason() + "").equals("null")? "": selectedList.get(i).getNopassReason() + "");
			sheetRow.createCell(12).setCellValue((selectedList.get(i).getAuditTime() + "").equals("null")? "": selectedList.get(i).getAuditTime() + "");
			//公共字段
			sheetRow.createCell(13).setCellValue((selectedList.get(i).getCreateTime() + "").equals("null")? "": selectedList.get(i).getCreateTime() + "");
			sheetRow.createCell(14).setCellValue((selectedList.get(i).getCreateBy() + "").equals("null")? "": selectedList.get(i).getCreateBy() + "");
			sheetRow.createCell(15).setCellValue((selectedList.get(i).getCreateName() + "").equals("null")? "": selectedList.get(i).getCreateName() + "");
			sheetRow.createCell(16).setCellValue((selectedList.get(i).getUpdateTime() + "").equals("null")? "": selectedList.get(i).getUpdateTime() + "");
			sheetRow.createCell(17).setCellValue((selectedList.get(i).getUpdateBy() + "").equals("null")? "": selectedList.get(i).getUpdateBy() + "");
			sheetRow.createCell(18).setCellValue((selectedList.get(i).getUpdateName() + "").equals("null")? "": selectedList.get(i).getUpdateName() + "");
			sheetRow.createCell(19).setCellValue((selectedList.get(i).getDeleteStatus() + "").equals("null")? "": selectedList.get(i).getDeleteStatus() + "");
		}
		//建立输出流，输出文件
		FileOutputStream fos = new FileOutputStream(filepath);

		workbook.write(fos);
		fos.flush();
		//关闭输出流
		fos.close();
		workbook.close();
		System.out.println("\n数据导出完成!");
		return "数据导出完成!";
	}
}
